@@ -68,8 +68,8 @@ class FileSystemManager(object):
                   'msdos': '83',
                   'ssd': ['ssd', 'discard', 'space_cache'],
                   'type': ['hdd', 'usb-hdd'],
-                  'compatible': ['btrfs-comp']},
-        'btrfs-comp': {'defaultopt': defaultOpt,
+                  'compatible': ['btrfs-compress']},
+        'btrfs-compress': {'defaultopt': defaultOpt,
                   'format': '/sbin/mkfs.btrfs',
                   'orig': 'btrfs',
                   'formatparam': '{labelparam} -f {device}',
