@@ -381,7 +381,7 @@ class VariableClGrubImageHash(ReadonlyVariable):
         return hashlib.md5(readFile(source)).hexdigest()
 
     def get_config_md5(selfself, source):
-        return hashlib.md5(readFile(source, grab=True)).hexdigest()
+        return hashlib.md5(readFileEx(source, grab=True)).hexdigest()
 
     def get_checksum(self):
         data = []
@@ -421,7 +421,7 @@ class VariableClSplashImageHash(ReadonlyVariable):
     cfg_files = "/etc/splash/calculate/*.cfg"
 
     def get_config_md5(selfself, source):
-        return hashlib.md5(readFile(source, grab=True)).hexdigest()
+        return hashlib.md5(readFileEx(source, grab=True)).hexdigest()
 
     def get_hash_data(self, sources):
         data = []
