@@ -1326,6 +1326,14 @@ class VariableOsLocationFormat(LocationHelper, Variable):
                                   where='os_format_use',
                                   eq='yes'))
 
+        default_format = None
+        if self.Get('os_root_type_ext') in RootType.HDD:
+            root_format = self.select(
+                'os_disk_format', os_disk_mount="/", limit=1)
+            if root_format and self.select(
+                'os_format_use', os_format_type=root_format, limit=1) == "yes":
+                default_format = root_format
+
         def wrap(info):
             dev, mount, fs = info
             if mount and not fs and dev.startswith('/dev/'):
@@ -1341,8 +1349,10 @@ class VariableOsLocationFormat(LocationHelper, Variable):
                             return diskFormat[dev]
                     else:
                         return diskFormat[dev]
-                return FileSystemManager.defaultFS.get(osInstallRootType,
-                                                       "ext4")
+                if default_format:
+                    return default_format
+                return FileSystemManager.defaultFS.get(
+                    osInstallRootType, "ext4")
             return fs
 
         return wrap
