@@ -480,9 +480,9 @@ class VariableClMigrateUserPwd(UserHelper, Variable):
             migrateusers = self.Get("cl_migrate_user")
             if migrateusers:
                 lenData = 9
-                shadowData = filter(lambda x: len(x) == lenData,
-                                    map(lambda x: x.rstrip().split(":"),
-                                        open(fileName)))
+                with open(fileName) as f:
+                    shadowData = filter(lambda x: len(x) == lenData,
+                                        map(lambda x: x.rstrip().split(":"), f))
                 shadowData = filter(lambda x: x[0] in migrateusers, shadowData)
                 shadowData = map(lambda x: (x[0], x[1]), shadowData)
                 shadowUsers = map(lambda x: x[0], shadowData)
